@@ -64,7 +64,7 @@ H5Lexists <- function( h5loc, name ) {
   Lexists = TRUE
   i=1
   while ((i <= length(name)) && (Lexists)) {
-    res <- .Call("_H5Lexists", h5loc@ID, paste(name[1:i],collapse="/"), PACKAGE='rhdf5')
+    res <- .Call("_H5Lexists", h5loc@ID, paste(head(name, n = i), collapse="/"), PACKAGE='rhdf5')
     Lexists <- ifelse(res > 0, TRUE, FALSE)
     i <- i + 1
   }
